@@ -144,19 +144,19 @@ builtin_theme <- function(dark = getOption("cli_theme_dark", "auto")) {
 }
 
 detect_dark_theme <- function(dark) {
-  if (dark == "auto") {
-    dark <- if (Sys.getenv("RSTUDIO", "0") == "1") {
-      tryCatch(
-        rstudioapi::getThemeInfo()$dark,
-        error = function(x) FALSE)
-    } else if (is_iterm()) {
-      is_iterm_dark()
-    } else {
-      FALSE
+  tryCatch({
+    if (dark == "auto") {
+      dark <- if (Sys.getenv("RSTUDIO", "0") == "1") {
+        rstudioapi::getThemeInfo()$dark
+      } else if (is_iterm()) {
+        is_iterm_dark()
+      } else {
+        FALSE
+      }
     }
-  }
+  }, error = function(e) FALSE)
 
-  dark
+  isTRUE(dark)
 }
 
 theme_code <- function(dark) {
@@ -176,34 +176,16 @@ theme_function <- function(dark) {
 }
 
 format_r_code <- function(dark) {
-  fun <- format_code(dark)
   function(x) {
     x <- crayon::strip_style(x)
     lines <- strsplit(x, "\n", fixed = TRUE)[[1]]
-    code <- tryCatch(prettycode::highlight(lines), error = function(x) lines)
-    fun(code)
+    tryCatch(prettycode::highlight(lines), error = function(x) lines)
   }
 }
 
 format_code <- function(dark) {
-  dark <- dark
-  style <- if (dark) {
-    crayon::combine_styles(
-      crayon::make_style("#232323", bg = TRUE),
-      crayon::make_style("#d0d0d0")
-    )
-  } else {
-    crayon::combine_styles(
-      crayon::make_style("#e8e8e8", bg = TRUE),
-      crayon::make_style("#202020")
-    )
-  }
   function(x) {
-    lines <- c("", unlist(strsplit(x, "\n", fixed = TRUE)), "")
-    len <- fansi::nchar_ctl(lines)
-    width <- console_width()
-    padded <- paste0(" ", lines, strrep(" ", width - len), " ")
-    style(padded)
+    unlist(strsplit(x, "\n", fixed = TRUE))
   }
 }
 
